rm(list=ls())
library(dplR)

load("treeringdata.RData")

rm(kmni)


#### remove bad cores ####

exclude=as.character(na.omit(read.delim("selection_by_Jose.txt")$custom_removal))

# are all in colnames?
exclude %in% colnames(chrono)

# remove "exclude" from chrono
sel=!colnames(chrono) %in% exclude
chrono=chrono[, sel]

# save information on which cores we still have in our data
core.ids=colnames(chrono)

# define window length for detrending (tree-ring series and climate)
my.nyrs=10
# my.nyrs=11

#### detrend tree-ring series ####

## build series for each tree from core-series
trw=list()
for(i in unique(substr(colnames(chrono), 1, 4))){
  sel=substr(colnames(chrono), 1, 4)==i
  trw[[i]]=rowMeans(data.frame(chrono[, sel]), na.rm=T)
  plot(chrono[, sel])
}
# list to data frame
trw=do.call(cbind, trw)
trw[trw=="NaN"]=NA

# save list of which trees we still have in our data
tree.ids=colnames(trw)

# detrend tree series
trw.detr=detrend(data.frame(trw), make.plot = F, method="Spline", nyrs = my.nyrs)
# for all trees, plot original series, detrended series and spline
for(i in colnames(trw)){
  # plot original series
  plot(x=rownames(trw), y=trw[, i], type="l", col="grey", main=i)
  # ... detrended series
  points(x=rownames(trw.detr), y=trw.detr[, i], type="l")
  # and subtracted trend
  points(x=rownames(trw.detr), y=trw[, i]/trw.detr[, i], type="l", col="grey", lty=2)
  # export
  dev.copy2pdf(file=paste("output/detrending/", i, ".pdf", sep=""), out.type = "pdf")
}


#### CHRONOLOGIES (robost statistics with bi-weight mean averaging) ####
chrono.detr=list()
for(i in unique(substr(colnames(trw.detr), 1, 1))){
  sel=substr(colnames(trw.detr), 1, 1)==i
  chrono.detr[[i]]=data.frame(chron(trw.detr[, sel], prewhiten = F, biweight = T)[, 1])
  colnames(chrono.detr[[i]])=i
}
# list to data frame
chrono.detr=do.call(cbind, chrono.detr)
# years as rownames
rownames(chrono.detr)=rownames(trw.detr)


#### Save chronologies and also the "raw" core series #### 
for(i in colnames(chrono.detr)){
  # chronologies
  write.rwl(chrono.detr[, i, drop=F], paste("output/chronologies/", i, ".ref.rwl", sep=""))
  # cores
  write.rwl(chrono[, substr(colnames(chrono), 1, 1)==i], paste("output/chronologies/", i, ".cores.rwl", sep=""))
  
}

#### detrending climate data ####
climate=read.csv(file="CRU_climate_data.csv")
rownames(climate)=climate[, 1]
climate[,1]<-NULL

# index chronology
climate.index=apply(climate, MARGIN = 2, FUN = function(x) x/(mean(x)))
climate.corelation=cor(climate.index, climate)

climate.detr=detrend(climate, make.plot = F, method="Spline", nyrs = my.nyrs)
warnings() # 25 warnings for PDSI

# for all climate parameters, plot original series, detrended series and spline
for(i in colnames(climate.index)){
  # plot original series
  plot(x=rownames(climate.index), y=climate.index[, i], type="l", col="grey", main=i)
  # ... detrended series
  points(x=rownames(climate.detr), y=climate.detr[, i], type="l")
  # and subtracted trend
  points(x=rownames(climate.detr), y=climate.index[, i]/climate.detr[, i], type="l", col="grey", lty=2)
  # export
  dev.copy2pdf(file=paste("output/detrending/", i, ".pdf", sep=""), out.type = "pdf")
}

## detrending makes no sense for PDSI, so we input the original values here
sel=substr(colnames(climate), 1, 4)=="PDSI"
climate.detr[, sel]=climate[, sel]



#### Metadata to site level metadata ####
metadata.site=aggregate(dem~Standort, data=metadata, FUN="mean")



#### save output ####
save(list=c("chrono.detr", "climate", "climate.detr", "core.ids", "tree.ids", "metadata.site", "trw", "trw.detr"), file="1_detrending_and_data_preparation_output.RData")
