#### DCA (years as plots, trees as species) ####
# Q2: Does climate explain growth patterns?
rm(list = ls())
library(vegan)
library(psych)

# Read data
load("1_detrending_and_data_preparation_output.RData")
# ordihull_dem=tapply(metadata$dem,metadata$Standort,mean)[1:10]

# exclude N
chrono.detr[, "N"]<-NULL



#### Monthly correlations at each site ####

# ## example
# cor(chrono.detr[, "B"], climate.detr)
# cor.test(chrono.detr[, "B"], climate.detr[, "T_winter"])
# library(psych)
# cor.ci(cbind(chrono.detr[, "B"], rowMeans(climate.detr[, c("T_dec", "T_JAN", "T_FEB")])), plot=F, n.iter=1000)


## calculate for all sites and all climate parameters (silenced, as not to overwrite the results)
## visualize with heatmaps (trunkated to store bootstrap results sustainably)
## calculate for all sites and all climate parameters
dfcsv=data.frame(row.names = colnames(climate.detr))
df=list()
for(site.i in colnames(chrono.detr)){
  for(clim.i in colnames(climate.detr)){
    dummy.cor=cor.ci(cbind(chrono.detr[, site.i], climate.detr[, clim.i]), plot=F, n.iter=1000)
    dummy.cor.p=dummy.cor$ci$p
    dummy.cor.rho=dummy.cor$rho[1, 2]

    # output to csv file
    # write R* if significant, otherwise only state R; output to csv file
    if(dummy.cor.p<0.05){
      dfcsv[clim.i, site.i]=paste(round(dummy.cor.rho, 2), "*", sep="")
    }else{
      dfcsv[clim.i, site.i]=round(dummy.cor.rho, 2)
    }

    # write output for heatmaps
    df[[paste(site.i, clim.i, sep="_")]]=data.frame(site=site.i, parameter=clim.i, rho=dummy.cor.rho, p=dummy.cor.p, signif=dummy.cor.p<0.05)

    print(paste(site.i, clim.i))
  }
}

##csv output
# order by elevation (top to bottom)
dfcsv=dfcsv[, c("B", "C", "F", "G", "H", "D", "K", "L", "M", "E")]
# save output
write.csv(dfcsv, file="output/site.climate.correlations.csv")

## df output (for heatmaps)
# list to data frame
df=do.call(rbind, df)




# add information about elevation
head(df)
head(metadata.site)
df=merge(df, metadata.site, by.x="site", by.y="Standort", all.x=T)
# factorial
df$f.dem=factor(round(df$dem))

# add parameter type
dummy=strsplit(as.character(df$parameter), split="_")
dummy=do.call(rbind, dummy)[, 1]
df$parameter.type=dummy; rm(dummy)

# # delete summer/winter parameters and NOV-DEC measurements
# dummy=strsplit(as.character(df$parameter), split="_")
# dummy=do.call(rbind, dummy)[, 2]
# sel=dummy=="summer"|dummy=="winter"|dummy=="NOV"|dummy=="DEC"
# df=df[!sel, ]; rm(dummy, sel)


# delete summer/winter parameters
dummy=strsplit(as.character(df$parameter), split="_")
dummy=do.call(rbind, dummy)[, 2]
sel=dummy=="summer"|dummy=="winter"
df=df[!sel, ]; rm(dummy, sel)


# reverse order of month
df$parameter=factor(df$parameter, levels=rev(levels(df$parameter)))

# add month
dummy=strsplit(as.character(df$parameter), split="_")
dummy=do.call(rbind, dummy)[, 2]
df$month=factor(dummy, levels=rev(c("jul", "aug", "sep", "oct", "nov", "dec", "JAN", "FEB", "MAR", "APR", "MAY", "JUN", "JUL", "AUG", "SEP", "OCT", "NOV", "DEC")))
rm(dummy)

# rename levels of climate data
df$parameter.type=factor(df$parameter.type)
levels(df$parameter.type)
levels(df$parameter.type)<-c("Precipitation", "PDSI - Palmer Drought Severity Index", "Sea surface temperature", "Temperature")

## exclude sites E, L, and C from analysis due to low EPS values
sel=df$site %in% c("E", "L", "C")
sel=df$site %in% c("E", "L")
df=df[!sel, ]

## ggplotting
library(ggplot2)

## color plot
ggplot()+
  aes(x=f.dem, y=month, fill=rho)+
  # fill with rho
  geom_tile(data=df)+
  # add yellow surrounding to significant correlations
  geom_tile(data=df[df$signif==T, ], fill=NA, col="yellow", size=1)+
  # facetting
  facet_wrap(facets=~parameter.type)+
  # design
  xlab("Elevation (m. a.s.l.)")+
  ylab("Month")+
  scale_fill_gradient2(low="red", mid="white", high="blue", name="Correlation\n(rho)")+
  theme_bw()+theme(panel.grid=element_blank(), axis.text.x=element_text(angle = 90, hjust = 1, vjust=0.5), legend.position = "right", text=element_text(size=10))
ggsave(filename = "output/site.climate.correlations.pdf", width=17, height = 20, units="cm")






## greyscale plot
ggplot()+
  aes(x=f.dem, y=month, fill=rho)+
  # fill with rho
  geom_tile(data=df)+
  # add black surrounding to significant correlations
  geom_tile(data=df[df$signif==T, ], fill=NA, col="black", size=1)+
  # add "+" for significantly positive relationships
  geom_text(data=df[df$rho>0, ], label="+")+
  # add "-" for significantly negative relationships
  geom_text(data=df[df$rho<0, ], label="-")+
  # facetting
  facet_wrap(facets=~parameter.type)+
  # design
  xlab("Elevation (m. a.s.l.)")+
  ylab("Month")+
  scale_fill_gradient2(low="grey50", mid="white", high="grey50", name="Correlation\n(rho)")+
  theme_bw()+theme(panel.grid=element_blank(), axis.text.x=element_text(angle = 90, hjust = 1, vjust=0.5), legend.position = "right", text=element_text(size=10))
ggsave(filename = "output/site.climate.correlations.greyscale.pdf", width=17, height = 20, units="cm")


