## load data
rm(list=ls())

library(dplR)

load("1_detrending_and_data_preparation_output.RData")
# define gradient (highest to lowest elevation)
gradient=c("B", "C", "F", "G", "H", "D", "K", "L", "M", "E", "N")


#### Chronology statistics ####

## define site id
head(trw.detr)
site.id=substr(colnames(trw.detr), 1, 1)

rwi.output=list()
for(i in gradient){
  sel=site.id==i
  rwi.output[[i]]=data.frame(site=i, rwi.stats(trw.detr[, sel], min.corr.overlap = 0, prewhiten=F))
}
rwi.output=do.call(rbind, rwi.output)
rwi.output

## merge elevation data
rwi.output=merge(rwi.output, metadata.site, by.x="site", by.y="Standort")
# re-order from highest to lowest sites
rwi.output=rwi.output[rev(order(rwi.output$dem)), ]
rwi.output

#### Prepare basic data table ####
df=rwi.output[, c("site", "n.trees", "eps", "dem", "rbar.tot")]
colnames(df)[colnames(df)=="dem"]="Elevation"
colnames(df)[colnames(df)=="eps"]="EPS"
colnames(df)[colnames(df)=="n.trees"]="N"

#### Gleichläufigkeit ####
glk.mean=list()
for(i in gradient){
  sel=site.id==i&colnames(trw.detr)!="B_09"
  glk.mean[[i]]=data.frame(site=i, GLK=mean(glk(trw.detr[, sel]), na.rm=T))
}
glk.mean=do.call(rbind, glk.mean)
glk.mean

## merge to table output
df=merge(df, glk.mean)


# ## blockwise Gleichläufigkeit
# sel=site.id=="B"|site.id=="C"|site.id=="F"
# mean(glk(trw.detr[, sel]), na.rm=T)


#### "COFECHA" interseries correlation (correlation with master) ####
ic.mean=list()
for(i in gradient){
  sel=site.id==i
  dummy.ic=interseries.cor(trw.detr[, sel], prewhiten = F, biweight = T)
  print(dummy.ic)
  print("Mean")
  mean(dummy.ic[, 1])
  print("SD")
  sd(dummy.ic[, 1])
  # output 
  dummy.ic.out=paste(round(mean(dummy.ic[, 1]),2), "±", round(sd(dummy.ic[, 1]), 2), sep="")
  ic.mean[[i]]=data.frame(site=i, IC=mean(dummy.ic[, 1]), SD_IC=sd(dummy.ic[, 1]), IC_and_SD=dummy.ic.out)
  
}
ic.mean=do.call(rbind, ic.mean)
df=merge(df, ic.mean[, 1:2])

sel=c("C_07", "C_44", "C_21", "C_01", "C_41")
rwi.stats(trw.detr[, sel], min.corr.overlap=0)
interseries.cor(trw.detr[, sel], prewhiten = F, biweight = T)
mean(interseries.cor(trw.detr[, sel], prewhiten = F, biweight = T)[, 1])



#### Share of missing rings per chronology ####
load("C:/Users/Robert/Documents/La_Palma_Veröffentlichung/statistics_for_revision_1.01_AoB_Plants/10yrs_spline_detrending/Figure 5 DCA and monthly climate variables/treeringdata.RData")
missingrings=chrono[, core.ids]

missingrings.df=list()
for(i in gradient){
  # select site
sel=substr(colnames(missingrings),1,1)==i
# extract number of missing rings
sum(missingrings[, sel]==0, na.rm=T)
# extract number of dated rings
sum(!is.na(missingrings[, sel]))
# calculate ratio and export
missingrings.df[[i]]=data.frame(site=i, missing_rings=100*sum(missingrings[, sel]==0, na.rm=T)/sum(!is.na(missingrings[, sel])))
}
# unlist
missingrings.df=do.call(rbind, missingrings.df)

## merge to table output
df=merge(df, missingrings.df)



#### Output of Table 1 ####
rownames(df)=df$site
df[gradient, c("Elevation", "N", "EPS", "rbar.tot", "missing_rings")]



write.csv(df[gradient, c("Elevation", "N", "EPS", "rbar.tot", "missing_rings")], "Table1.csv")



#### Correlations of chronology statistics with Elevation ####
plot(df[gradient, c(4, 3, 5, 6)])
cor(df[gradient, c(4, 3, 5, 6)], method="pearson")
for(i in c(3, 5, 6)){
  print(colnames(df)[i])
  print(cor.test(df[gradient, 4], df[gradient, i], method="pearson"))
}


#### Correlation between chronologies ####
interseries.cor(chrono.detr[, gradient])





#### rwi.stats for different conglomerates of sites ####
sel=site.id=="M"|site.id=="K"
rwi.stats(trw.detr[, sel], min.corr.overlap = 0, prewhiten=F)

